@@ -9,4 +9,7 @@ EXPRESSION_METADATA = {
     exp.Coalesce: {
         "annotator": lambda self, e: self._annotate_by_args(e, "this", "expressions", promote=True)
     },
+    exp.Encode: {"returns": exp.DataType.Type.BINARY},
+    exp.StrToUnix: {"returns": exp.DataType.Type.BIGINT},
+    exp.Tanh: {"returns": exp.DataType.Type.DOUBLE},
 }
