@@ -180,6 +180,29 @@ def _annotate_variance(self: TypeAnnotator, expression: exp.Expression) -> exp.E
     return expression
 
 
+def _annotate_kurtosis(self: TypeAnnotator, expression: exp.Kurtosis) -> exp.Kurtosis:
+    """Annotate KURTOSIS with correct return type.
+
+    Based on Snowflake behavior:
+    - DECFLOAT input -> DECFLOAT
+    - DOUBLE or FLOAT input -> DOUBLE
+    - Other numeric types (INT, NUMBER) -> NUMBER(38, 12)
+    """
+    expression = self._annotate_by_args(expression, "this")
+    input_type = expression.this.type
+
+    if input_type.is_type(exp.DataType.Type.DECFLOAT):
+        self._set_type(expression, exp.DataType.build("DECFLOAT", dialect="snowflake"))
+    elif input_type.is_type(exp.DataType.Type.FLOAT, exp.DataType.Type.DOUBLE):
+        self._set_type(expression, exp.DataType.Type.DOUBLE)
+    else:
+        self._set_type(
+            expression, exp.DataType.build(f"NUMBER({MAX_PRECISION}, 12)", dialect="snowflake")
+        )
+
+    return expression
+
+
 def _annotate_math_with_float_decfloat(
     self: TypeAnnotator, expression: exp.Expression
 ) -> exp.Expression:
@@ -239,10 +262,16 @@ EXPRESSION_METADATA = {
         for expr_type in (
             exp.ApproxTopK,
             exp.ApproxTopKEstimate,
+            exp.Array,
             exp.ArrayAgg,
+            exp.ArrayAppend,
+            exp.ArrayConcat,
             exp.ArrayConstructCompact,
+            exp.ArrayPrepend,
+            exp.ArrayRemove,
             exp.ArrayUniqueAgg,
             exp.ArrayUnionAgg,
+            exp.MapKeys,
             exp.RegexpExtractAll,
             exp.Split,
             exp.StringToArray,
@@ -270,6 +299,10 @@ EXPRESSION_METADATA = {
             exp.BitmapOrAgg,
             exp.Compress,
             exp.DecompressBinary,
+            exp.Decrypt,
+            exp.DecryptRaw,
+            exp.Encrypt,
+            exp.EncryptRaw,
             exp.HexString,
             exp.MD5Digest,
             exp.SHA1Digest,
@@ -289,6 +322,7 @@ EXPRESSION_METADATA = {
             exp.BoolxorAgg,
             exp.EqualNull,
             exp.IsNullValue,
+            exp.MapContainsKey,
             exp.Search,
             exp.SearchIp,
             exp.ToBoolean,
@@ -326,6 +360,8 @@ EXPRESSION_METADATA = {
             exp.Cbrt,
             exp.Cosh,
             exp.CosineDistance,
+            exp.CovarPop,
+            exp.CovarSamp,
             exp.DotProduct,
             exp.EuclideanDistance,
             exp.ManhattanDistance,
@@ -334,6 +370,7 @@ EXPRESSION_METADATA = {
             exp.Sinh,
         }
     },
+    exp.Kurtosis: {"annotator": _annotate_kurtosis},
     **{
         expr_type: {"returns": exp.DataType.Type.DECFLOAT}
         for expr_type in {
@@ -385,6 +422,7 @@ EXPRESSION_METADATA = {
             exp.JarowinklerSimilarity,
             exp.Length,
             exp.Levenshtein,
+            exp.MapSize,
             exp.Minute,
             exp.RtrimmedLength,
             exp.Second,
@@ -406,6 +444,15 @@ EXPRESSION_METADATA = {
             exp.XMLGet,
         }
     },
+    **{
+        expr_type: {"returns": exp.DataType.Type.MAP}
+        for expr_type in {
+            exp.MapCat,
+            exp.MapDelete,
+            exp.MapInsert,
+            exp.MapPick,
+        }
+    },
     **{
         expr_type: {"returns": exp.DataType.Type.FILE}
         for expr_type in {
@@ -419,6 +466,13 @@ EXPRESSION_METADATA = {
             exp.TsOrDsToTime,
         }
     },
+    **{
+        expr_type: {"returns": exp.DataType.Type.TIMESTAMPLTZ}
+        for expr_type in {
+            exp.CurrentTimestamp,
+            exp.Localtimestamp,
+        }
+    },
     **{
         expr_type: {"returns": exp.DataType.Type.VARCHAR}
         for expr_type in {
@@ -453,7 +507,6 @@ EXPRESSION_METADATA = {
             exp.DecompressString,
             exp.HexDecodeString,
             exp.HexEncode,
-            exp.Initcap,
             exp.MD5,
             exp.Monthname,
             exp.Randstr,
@@ -500,15 +553,11 @@ EXPRESSION_METADATA = {
     },
     exp.DateAdd: {"annotator": _annotate_date_or_time_add},
     exp.DecodeCase: {"annotator": _annotate_decode_case},
-    exp.GreatestIgnoreNulls: {
-        "annotator": lambda self, e: self._annotate_by_args(e, "expressions")
-    },
     exp.HashAgg: {
         "annotator": lambda self, e: self._set_type(
             e, exp.DataType.build("NUMBER(19, 0)", dialect="snowflake")
         )
     },
-    exp.LeastIgnoreNulls: {"annotator": lambda self, e: self._annotate_by_args(e, "expressions")},
     exp.Median: {"annotator": _annotate_median},
     exp.Reverse: {"annotator": _annotate_reverse},
     exp.StrToTime: {"annotator": _annotate_str_to_time},
