@@ -22,6 +22,9 @@ DOUBLE;
 CURRENT_TIME();
 TIME;
 
+LOCALTIME();
+TIME;
+
 TIME_ADD(CAST('09:05:03' AS TIME), INTERVAL 2 HOUR);
 TIME;
 
@@ -320,6 +323,47 @@ INTERVAL;
 COALESCE(tbl.bin_col, tbl.str_col);
 BINARY;
 
+# dialect: spark, databricks
+LOCALTIMESTAMP();
+TIMESTAMPNTZ;
+
+# dialect: hive, spark2, spark, databricks
+ENCODE(tbl.str_col, tbl.str_col);
+BINARY;
+
+# dialect: hive, spark2, spark, databricks
+ENCODE(tbl.bin_col, tbl.bin_col);
+BINARY;
+
+# dialect: spark, databricks
+CURRENT_TIMEZONE();
+STRING;
+
+# dialect: hive, spark2, spark, databricks
+UNIX_TIMESTAMP();
+BIGINT;
+
+# dialect: spark2, spark, databricks
+ATAN2(tbl.int_col, tbl.int_col);
+DOUBLE;
+
+# dialect: spark2, spark, databricks
+ATAN2(tbl.double_col, tbl.double_col);
+DOUBLE;
+
+# dialect: spark2, spark, databricks
+ATAN2(tbl.double_col, tbl.int_col);
+DOUBLE;
+
+# dialect: hive, spark2, spark, databricks
+TANH(tbl.double_col);
+DOUBLE;
+
+# dialect: hive, spark2, spark, databricks
+TANH(tbl.int_col);
+DOUBLE;
+
+
 --------------------------------------
 -- BigQuery
 --------------------------------------
@@ -1676,6 +1720,14 @@ DATETIME;
 IF(TRUE, '00:00:00', TIME '00:01:00');
 TIME;
 
+# dialect: bigquery
+IF(TRUE, 1, CAST(2.5 AS BIGNUMERIC));
+BIGNUMERIC;
+
+# dialect: bigquery
+IF(TRUE, 1.5, 2.5);
+FLOAT64;
+
 # dialect: bigquery
 IF(TRUE, '2010-01-01 00:00:00', TIMESTAMP '2020-02-02 00:00:00');
 TIMESTAMP;
@@ -1704,6 +1756,10 @@ STRING;
 ANY_VALUE(c2::STRING HAVING MAX c1::INT64);
 STRING;
 
+# dialect: bigquery
+r'a';
+STRING;
+
 --------------------------------------
 -- Snowflake
 --------------------------------------
@@ -1724,6 +1780,10 @@ DATE;
 ADD_MONTHS(tbl.timestamp_col, -1);
 TIMESTAMP;
 
+# dialect: snowflake
+ARRAY_CONSTRUCT();
+ARRAY;
+
 # dialect: snowflake
 ARRAY_CONSTRUCT_COMPACT();
 ARRAY;
@@ -1732,6 +1792,22 @@ ARRAY;
 ARRAY_CONSTRUCT_COMPACT(1, null, 2);
 ARRAY;
 
+# dialect: snowflake
+ARRAY_APPEND([1, 2, 3], 4);
+ARRAY;
+
+# dialect: snowflake
+ARRAY_CAT([1, 2], [3, 4]);
+ARRAY;
+
+# dialect: snowflake
+ARRAY_PREPEND([2, 3, 4], 1);
+ARRAY;
+
+# dialect: snowflake
+ARRAY_REMOVE([1, 2, 3], 2);
+ARRAY;
+
 # dialect: snowflake
 ASIN(tbl.double_col);
 DOUBLE;
@@ -1756,6 +1832,22 @@ DOUBLE;
 CBRT(tbl.double_col);
 DOUBLE;
 
+# dialect: snowflake
+COVAR_POP(tbl.double_col, tbl.double_col);
+DOUBLE;
+
+# dialect: snowflake
+COVAR_SAMP(tbl.double_col, tbl.double_col);
+DOUBLE;
+
+# dialect: snowflake
+COVAR_POP(tbl.double_col, tbl.double_col) OVER (PARTITION BY 1);
+DOUBLE;
+
+# dialect: snowflake
+COVAR_SAMP(tbl.double_col, tbl.double_col) OVER (PARTITION BY 1);
+DOUBLE;
+
 # dialect: snowflake
 AI_AGG('foo', 'bar');
 VARCHAR;
@@ -2800,6 +2892,38 @@ VARCHAR;
 INSERT(tbl.bin_col, 1, 2, tbl.bin_col);
 BINARY;
 
+# dialect: snowflake
+KURTOSIS(tbl.double_col);
+DOUBLE;
+
+# dialect: snowflake
+KURTOSIS(tbl.double_col) OVER (PARTITION BY 1);
+DOUBLE;
+
+# dialect: snowflake
+KURTOSIS(tbl.float_col);
+DOUBLE;
+
+# dialect: snowflake
+KURTOSIS(tbl.float_col) OVER (PARTITION BY 1);
+DOUBLE;
+
+# dialect: snowflake
+KURTOSIS(tbl.int_col);
+NUMBER(38, 12);
+
+# dialect: snowflake
+KURTOSIS(tbl.int_col) OVER (PARTITION BY 1);
+NUMBER(38, 12);
+
+# dialect: snowflake
+KURTOSIS(tbl.decfloat_col);
+DECFLOAT;
+
+# dialect: snowflake
+KURTOSIS(tbl.decfloat_col) OVER (PARTITION BY 1);
+DECFLOAT;
+
 # dialect: snowflake
 LEAST(x::DECIMAL(18, 2));
 DECIMAL(18, 2);
@@ -2848,6 +2972,18 @@ INT;
 LENGTH(tbl.bin_col);
 INT;
 
+# dialect: snowflake
+LOCALTIMESTAMP;
+TIMESTAMPLTZ;
+
+# dialect: snowflake
+LOCALTIMESTAMP();
+TIMESTAMPLTZ;
+
+# dialect: snowflake
+LOCALTIMESTAMP(3);
+TIMESTAMPLTZ;
+
 # dialect: snowflake
 OCTET_LENGTH(tbl.str_col);
 INT;
@@ -2952,6 +3088,34 @@ VARCHAR;
 LTRIM(NULL);
 VARCHAR;
 
+# dialect: snowflake
+MAP_CAT(CAST(col AS MAP(VARCHAR, VARCHAR)), CAST(col AS MAP(VARCHAR, VARCHAR)));
+MAP;
+
+# dialect: snowflake
+MAP_CONTAINS_KEY('k1', CAST(col AS MAP(VARCHAR, VARCHAR)));
+BOOLEAN;
+
+# dialect: snowflake
+MAP_DELETE(CAST(col AS MAP(VARCHAR, VARCHAR)), 'b');
+MAP;
+
+# dialect: snowflake
+MAP_INSERT(CAST(col AS MAP(VARCHAR, VARCHAR)), 'b', '2');
+MAP;
+
+# dialect: snowflake
+MAP_KEYS(CAST(col AS MAP(VARCHAR, VARCHAR)));
+ARRAY;
+
+# dialect: snowflake
+MAP_PICK(CAST(col AS MAP(VARCHAR, VARCHAR)), 'a', 'c');
+MAP;
+
+# dialect: snowflake
+MAP_SIZE(CAST(col AS MAP(VARCHAR, VARCHAR)));
+INT;
+
 # dialect: snowflake
 MINUTE(CAST('08:50:57' AS TIME));
 INT;
@@ -3732,6 +3896,14 @@ TIME;
 TRY_TO_TIME('12:30:00', 'AUTO');
 TIME;
 
+# dialect: snowflake
+TO_TIME('093000', 'HH24MISS');
+TIME;
+
+# dialect: snowflake
+TRY_TO_TIME('093000', 'HH24MISS');
+TIME;
+
 # dialect: snowflake
 TO_TIMESTAMP('2024-01-15 12:30:00');
 TIMESTAMP;
@@ -3772,6 +3944,30 @@ TIMESTAMP;
 TRY_TO_TIMESTAMP('2024-01-15 12:30:00', 'AUTO');
 TIMESTAMP;
 
+# dialect: snowflake
+TRY_TO_TIMESTAMP_LTZ('2024-01-15 12:30:00');
+TIMESTAMPLTZ;
+
+# dialect: snowflake
+TRY_TO_TIMESTAMP_LTZ('2024-01-15 12:30:00', 'AUTO');
+TIMESTAMPLTZ;
+
+# dialect: snowflake
+TRY_TO_TIMESTAMP_NTZ('2024-01-15 12:30:00');
+TIMESTAMPNTZ;
+
+# dialect: snowflake
+TRY_TO_TIMESTAMP_NTZ('2024-01-15 12:30:00', 'AUTO');
+TIMESTAMPNTZ;
+
+# dialect: snowflake
+TRY_TO_TIMESTAMP_TZ('2024-01-15 12:30:00');
+TIMESTAMPTZ;
+
+# dialect: snowflake
+TRY_TO_TIMESTAMP_TZ('2024-01-15 12:30:00', 'AUTO');
+TIMESTAMPTZ;
+
 # dialect: snowflake
 ABS(CAST(-123.456 AS DECFLOAT));
 DECFLOAT;
@@ -4052,6 +4248,30 @@ BOOLEAN;
 SEARCH_IP(col, '192.168.0.0');
 BOOLEAN;
 
+# dialect: snowflake
+STDDEV(tbl.double_col);
+DOUBLE;
+
+# dialect: snowflake
+STDDEV(tbl.double_col) OVER (PARTITION BY 1);
+DOUBLE;
+
+# dialect: snowflake
+STDDEV_POP(tbl.double_col);
+DOUBLE;
+
+# dialect: snowflake
+STDDEV_POP(tbl.double_col) OVER (PARTITION BY 1);
+DOUBLE;
+
+# dialect: snowflake
+STDDEV_SAMP(tbl.double_col);
+DOUBLE;
+
+# dialect: snowflake
+STDDEV_SAMP(tbl.double_col) OVER (PARTITION BY 1);
+DOUBLE;
+
 # dialect: snowflake
 STRTOK_TO_ARRAY('a,b,c', ',');
 ARRAY;
@@ -4648,6 +4868,86 @@ NUMBER(38, 15);
 VARIANCE_POP(1::NUMBER(30, 5));
 NUMBER(38, 12);
 
+# dialect: snowflake
+ENCRYPT(tbl.str_col, 'passphrase');
+BINARY;
+
+# dialect: snowflake
+ENCRYPT(tbl.str_col, 'passphrase', 'aad');
+BINARY;
+
+# dialect: snowflake
+ENCRYPT(tbl.str_col, 'passphrase', 'aad', 'AES-GCM');
+BINARY;
+
+# dialect: snowflake
+ENCRYPT_RAW(tbl.str_col, tbl.key_col, tbl.iv_col);
+BINARY;
+
+# dialect: snowflake
+ENCRYPT_RAW(tbl.str_col, tbl.key_col, tbl.iv_col, tbl.aad_col);
+BINARY;
+
+# dialect: snowflake
+ENCRYPT_RAW(tbl.str_col, tbl.key_col, tbl.iv_col, tbl.aad_col, 'AES-GCM');
+BINARY;
+
+# dialect: snowflake
+DECRYPT(tbl.encrypted_col, 'passphrase');
+BINARY;
+
+# dialect: snowflake
+DECRYPT(tbl.encrypted_col, 'passphrase', 'aad');
+BINARY;
+
+# dialect: snowflake
+DECRYPT(tbl.encrypted_col, 'passphrase', 'aad', 'AES-GCM');
+BINARY;
+
+# dialect: snowflake
+DECRYPT_RAW(tbl.encrypted_col, tbl.key_col, tbl.iv_col);
+BINARY;
+
+# dialect: snowflake
+DECRYPT_RAW(tbl.encrypted_col, tbl.key_col, tbl.iv_col, tbl.aad_col);
+BINARY;
+
+# dialect: snowflake
+DECRYPT_RAW(tbl.encrypted_col, tbl.key_col, tbl.iv_col, tbl.aad_col, 'AES-GCM');
+BINARY;
+
+# dialect: snowflake
+DECRYPT_RAW(tbl.encrypted_col, tbl.key_col, tbl.iv_col, tbl.aad_col, 'AES-GCM', HEX_DECODE_BINARY('ff'));
+BINARY;
+
+# dialect: snowflake
+TRY_DECRYPT(tbl.encrypted_col, 'passphrase');
+BINARY;
+
+# dialect: snowflake
+TRY_DECRYPT(tbl.encrypted_col, 'passphrase', 'aad');
+BINARY;
+
+# dialect: snowflake
+TRY_DECRYPT(tbl.encrypted_col, 'passphrase', 'aad', 'AES-GCM');
+BINARY;
+
+# dialect: snowflake
+TRY_DECRYPT_RAW(tbl.encrypted_col, tbl.key_col, tbl.iv_col);
+BINARY;
+
+# dialect: snowflake
+TRY_DECRYPT_RAW(tbl.encrypted_col, tbl.key_col, tbl.iv_col, tbl.aad_col);
+BINARY;
+
+# dialect: snowflake
+TRY_DECRYPT_RAW(tbl.encrypted_col, tbl.key_col, tbl.iv_col, tbl.aad_col, 'AES-GCM');
+BINARY;
+
+# dialect: snowflake
+TRY_DECRYPT_RAW(tbl.encrypted_col, tbl.key_col, tbl.iv_col, tbl.aad_col, 'AES-GCM', HEX_DECODE_BINARY('ff'));
+BINARY;
+
 --------------------------------------
 -- T-SQL
 --------------------------------------
@@ -4659,3 +4959,15 @@ TIMESTAMPTZ;
 # dialect: tsql
 RADIANS(90);
 INT;
+
+--------------------------------------
+-- MySQL
+--------------------------------------
+
+# dialect: mysql
+LOCALTIME;
+DATETIME;
+
+# dialect: mysql
+ELT(1, 'a', 'b');
+VARCHAR;
\ No newline at end of file
