@@ -1070,6 +1070,7 @@ SELECT :with_,WITH :expressions,CTE :this,UNION :this,SELECT :expressions,1,:exp
                 "bignum_col": "BIGNUMERIC",
                 "date_col": "DATE",
                 "decfloat_col": "DECFLOAT",
+                "float_col": "FLOAT",
                 "timestamp_col": "TIMESTAMP",
                 "double_col": "DOUBLE",
                 "bigint_col": "BIGINT",
@@ -1917,6 +1918,66 @@ SELECT :with_,WITH :expressions,CTE :this,UNION :this,SELECT :expressions,1,:exp
 
         assert annotated.selects[0].type == exp.DataType.build("VARCHAR")
 
+    def test_bigquery_unnest_alias_shadowing(self):
+        """Test that BigQuery UNNEST table alias shadows column names from other tables."""
+        sql = """
+            SELECT timeline_date
+            FROM UNNEST(GENERATE_DATE_ARRAY('2020-01-01', '2020-01-03')) AS timeline_date
+            LEFT JOIN production_tier ON production_tier.timeline_date = timeline_date
+        """
+        schema = {"production_tier": {"timeline_date": "DATE", "id": "INT"}}
+
+        result = optimizer.qualify.qualify(
+            parse_one(sql, dialect="bigquery"),
+            schema=schema,
+            dialect="bigquery",
+        )
+
+        result_sql = result.sql(dialect="bigquery")
+        self.assertEqual(
+            result_sql,
+            "SELECT `timeline_date` AS `timeline_date` "
+            "FROM UNNEST(GENERATE_DATE_ARRAY('2020-01-01', '2020-01-03', INTERVAL '1' DAY)) AS `timeline_date` "
+            "LEFT JOIN `production_tier` AS `production_tier` "
+            "ON `production_tier`.`timeline_date` = `timeline_date`",
+        )
+
+    def test_struct_field_case_sensitivity_annotation(self):
+        schema = {"t": {"struct_col": "STRUCT<fooBar STRING>"}}
+
+        def _assert_dot_annotation(query: str, dialect: str, expected: exp.DataType.Type):
+            parsed = parse_one(query, dialect=dialect)
+            qualified = optimizer.qualify.qualify(parsed, schema=schema, dialect=dialect)
+            annotated = optimizer.annotate_types.annotate_types(
+                qualified, schema=schema, dialect=dialect
+            )
+            self.assertEqual(annotated.selects[0].type.this, expected)
+
+        # BigQuery is case-insensitive: exact field name match
+        _assert_dot_annotation(
+            "SELECT struct_col.fooBar FROM t", "bigquery", exp.DataType.Type.TEXT
+        )
+
+        # BigQuery: lower case
+        _assert_dot_annotation(
+            "SELECT struct_col.foobar FROM t", "bigquery", exp.DataType.Type.TEXT
+        )
+
+        # BigQuery: different case
+        _assert_dot_annotation(
+            "SELECT struct_col.Foobar FROM t", "bigquery", exp.DataType.Type.TEXT
+        )
+
+        # ClickHouse is case-sensitive: exact field name match
+        _assert_dot_annotation(
+            "SELECT struct_col.fooBar FROM t", "clickhouse", exp.DataType.Type.TEXT
+        )
+
+        # ClickHouse: lower case
+        _assert_dot_annotation(
+            "SELECT struct_col.foobar FROM t", "clickhouse", exp.DataType.Type.UNKNOWN
+        )
+
     def test_annotate_object_construct(self):
         sql = "SELECT OBJECT_CONSTRUCT('foo', 'bar', 'a b', 'c d') AS c"
 
